# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account_move
from . import res_company
from . import sale_order
from . import res_config_settings
from . import stock
from . import product_template
